@@ -149,6 +149,86 @@ lesson_t lessons[] = {
     "Press 'l' to toggle light\n"
     "Press cursor keys to move"
   },
+
+  {
+    "lesson11", "Lesson 11: Waving Texture",
+    "This tutorial builds on the code from lesson 6. By the end "
+    "of the tutorial you should be able to bend fold and manipulate "
+    "textures of your own.",
+    "http://nehe.gamedev.net/data/lessons/lesson.asp?lesson=11",
+    "lesson11",
+    "Tap screen to exit\n"
+  },
+
+  {
+    "lesson12", "Lesson 12: Display Lists",
+    "Prebuild objects and display them on the screen with just "
+    "one line of code. Speed up your programs by using precompiled "
+    "objects in your programs.",
+    "http://nehe.gamedev.net/data/lessons/lesson.asp?lesson=12",
+    "lesson12",
+    "Tap screen to exit\n"
+    "Press cursor keys to rotate objects"
+  },
+
+  {
+    "lesson16", "Lesson 16: Cool Looking Fog",
+    "You'll learn how to use 3 different fog filters, how to change the "
+    "color of the fog, and how to set how far into the screen the fog "
+    "starts and how far into the screen it ends.",
+    "http://nehe.gamedev.net/data/lessons/lesson.asp?lesson=16",
+    "lesson16",
+    "Tap screen to exit\n"
+    "Press 'f' to cycle through texture filters\n"
+    "Press 'g' to cycle through fog filters\n"
+    "Press 'l' to toggle light\n"
+    "Press 'i'/'o' to zoom in and out"
+    "Press cursor keys to rotate object"
+  },
+
+  {
+    "lesson18", "Lesson 18: Quadrics",
+    "This tutorial will introduce the world of quadrics. With quadrics "
+    "you can easily create complex objects such as spheres, discs, "
+    "cylinders and cones.",
+    "http://nehe.gamedev.net/data/lessons/lesson.asp?lesson=18",
+    "lesson18",
+    "Tap screen to exit\n"
+    "Press Space to cycle through objects\n"
+    "Press 'f' to cycle through texture filters\n"
+    "Press 'l' to toggle light\n"
+    "Press 'i'/'o' to zoom in and out"
+    "Press cursor keys to rotate object"
+  },
+
+  {
+    "lesson19", "Lesson 19: Particle Engine",
+    "You'll learn how to program a simple but nice looking particle "
+    "engine. I've thrown in a few extras like a rainbow mode, and "
+    "lots of keyboard interaction.",
+    "http://nehe.gamedev.net/data/lessons/lesson.asp?lesson=19",
+    "lesson19",
+    "Tap screen to exit\n"
+    "Press 'm'/'n' speed up/slow down particles\n"
+    "Press 'w', 'x', 'a' and 'd' to change gravity\n"
+    "Press 's' to explode all particles\n"
+    "Press SPACE to manually change colors\n"
+    "Press ENTER to toggle rainbow effect\n"
+    "Press 'i'/'o' to zoom in and out\n"
+    "Press cursor keys to change particles initial movement"
+  },
+
+  {
+    "lesson20", "Lesson 20: Masking",
+    "With the blending we have been using up until now, the scene will "
+    "shine through our objects. By combining some fancy blending with an "
+    "image mask, your text can be solid.",
+    "http://nehe.gamedev.net/data/lessons/lesson.asp?lesson=20",
+    "lesson20",
+    "Tap screen to exit\n"
+    "Press 'm' to toggle masking\n"
+    "Press SPACE to toggle scene display"
+  },
 };
 
 static void on_source_clicked(GtkButton *button, gpointer user) {
